@@ -60,8 +60,10 @@ static	void		  cria_presentation_get_property       (GObject		* object,
 								guint		  prop_id,
 								GValue		* value,
 								GParamSpec	* param_spec);
-static	CriaPresentation* cria_presentation_parse_input_xml    (GsfInput        * input);
-static	CriaPresentation* cria_presentation_new_from_input     (GsfInput	* input);
+static	CriaPresentation* cria_presentation_parse_input_xml    (GsfInput        * input,
+								GError		**error);
+static	CriaPresentation* cria_presentation_new_from_input     (GsfInput	* input,
+								GError		**error);
 static	void		  cria_presentation_init	       (CriaPresentation* self);
 static	void		  cria_presentation_set_property       (GObject		* object,
 								guint		  prop_id,
@@ -260,8 +262,7 @@ cria_presentation_n_slides (CriaPresentation        * self)
 }
 
 CriaPresentation*
-cria_presentation_new_from_file (const	gchar	* filename)
-{
+cria_presentation_new_from_file (const	gchar	* filename, GError**errloc) {
 	CriaPresentation* presentation;
 	GError		* error = NULL;
 	GsfInput	* input = NULL;
@@ -277,25 +278,27 @@ cria_presentation_new_from_file (const	gchar	* filename)
 				&error)
 			);
 
-	if (error)
-	{
-		g_warning ("(%s, %i): %s", __FILE__, __LINE__, error->message);
-		g_error_free (error);
+	if (error) {
+		*errloc = error;
 		return NULL;
 	}
 
-	presentation = cria_presentation_new_from_input (input);
+	presentation = cria_presentation_new_from_input (input, &error);
 	
-	g_debug ("cria_presentation_populate_from_file(%i): end", __LINE__);
+	if (error) {
+		*errloc = error;
+		return NULL;
+	}
 
 	return presentation;
 }
 
 static CriaPresentation*
 cria_presentation_new_from_input (
-		GsfInput	* input)
-{
+		GsfInput	* input,
+		GError		**errloc) {
 	CriaPresentation* presentation;
+	GError		* error = NULL;
 	
 	g_debug ("cria_presentation_populate_from_input(%i): start", __LINE__);
 
@@ -304,15 +307,17 @@ cria_presentation_new_from_input (
 	 * for examples)
 	 */
 	
-	presentation = cria_presentation_parse_input_xml (input);
+	presentation = cria_presentation_parse_input_xml (input, &error);
 	
-	g_debug ("cria_presentation_populate_from_input(%i): end", __LINE__);
+	if (error) {
+		*errloc = error;
+	}
 
 	return presentation;
 }
 
 CriaPresentation*
-cria_presentation_new_from_uri(const gchar* text_uri) {
+cria_presentation_new_from_uri(const gchar* text_uri, GError**errloc) {
 	CriaPresentation* presentation;
 	GError		* error = NULL;
 	GsfInput	* input = NULL;
@@ -327,12 +332,16 @@ cria_presentation_new_from_uri(const gchar* text_uri) {
 			);
 
 	if (error) {
-		g_warning ("(%s, %i): %s", __FILE__, __LINE__, error->message);
-		g_error_free (error);
+		*errloc = error;
 		return NULL;
 	}
 
-	presentation = cria_presentation_new_from_input (input);
+	presentation = cria_presentation_new_from_input (input, &error);
+
+	if (error) {
+		*errloc = error;
+		return NULL;
+	}
 	
 	return presentation;
 
@@ -399,6 +408,7 @@ typedef struct
 	GList			* tags;
 	guint			  unknown;
 	GString			* cdata;
+	GError			* error;
 } Sax001Data;
 
 typedef void (*cria_sax_start_element) (GHashTable	* attributes,
@@ -417,8 +427,7 @@ struct _cria_tag_data
 static xmlSAXHandler cria_0_0_1_handler;
 
 static CriaPresentation*
-cria_presentation_parse_input_xml (GsfInput *input)
-{
+cria_presentation_parse_input_xml (GsfInput *input, GError**error) {
 	CriaPresentation* presentation = NULL;
 	xmlParserCtxt	* context;
 	
@@ -431,13 +440,16 @@ cria_presentation_parse_input_xml (GsfInput *input)
 	// TODO validate against DTD
 	xmlParseDocument (context);
 
-	if (context->wellFormed)
-	{
+	if (((Sax001Data*)context->userData)->error) {
+		*error = ((Sax001Data*)context->userData)->error;
+		g_free(context->userData);
+		return NULL;
+	}
+
+	if (context->wellFormed) {
 		presentation = CRIA_PRESENTATION (((Sax001Data*)context->userData)->tags);
 		g_debug ("cria_presentation_parse_input_xml(%i): really good file", __LINE__);
-	}
-	else
-	{
+	} else {
 		g_debug ("cria_presentation_parse_input_xml(%i): really bad file", __LINE__);
 	}
 
@@ -451,22 +463,19 @@ static void
 cria_sax_0_0_1_characters (
 		gpointer	* user_data,
 		const	xmlChar	* string,
-		int		  length)
-{
+		int		  length) {
 	char		* str;
 	Sax001Data	* data = (Sax001Data*) user_data;
 	
 	/* return if empty */
-	if (!string)
-	{
+	if (!string) {
 		return;
 	}
 
 	str = g_strndup (string, length);
 	g_strstrip (str);
 	
-	if (strlen (str))
-	{
+	if (strlen (str)) {
 		/* just do this if we really have some data to care about */
 		char	**strv,
 			**iterator;
@@ -485,11 +494,11 @@ cria_sax_0_0_1_characters (
 				"\n",
 				0);
 
-		if (!data->cdata)
+		if (!data->cdata) {
 			data->cdata = g_string_new ("");
+		}
 
-		for (iterator = strv; *iterator; iterator++)
-		{
+		for (iterator = strv; *iterator; iterator++) {
 			g_strstrip (*iterator);
 
 			/* append one whitespace between lines */
@@ -505,15 +514,19 @@ cria_sax_0_0_1_characters (
 static void
 cria_sax_0_0_1_element_background_start (
 		GHashTable	* hash_table,
-		Sax001Data	* data)
-{
+		Sax001Data	* data) {
+	GError	* error = NULL;
 	g_return_if_fail (CRIA_IS_LAYOUT (g_list_last (data->tags)->data));
 
 	data->tags = g_list_append (
-			data->tags,
-			// TODO add error handling
-			gdk_pixbuf_new_from_file (g_hash_table_lookup (hash_table, "file"), NULL)
+				data->tags,
+				// TODO add error handling
+				gdk_pixbuf_new_from_file (g_hash_table_lookup (hash_table, "file"), &error)
 			);
+
+	if (error) {
+		data->error = error;
+	}
 }
 
 static void
@@ -888,34 +901,35 @@ cria_0_0_1_start_element (
 	
 	sax_data = (Sax001Data*) userdata;
 
-	if (sax_data->unknown == 0)
-	{
+	if (sax_data->error != NULL) {
+		/* if we already have entered some invalid state the just do not try to make
+		 * more damage happen
+		 */
+		return;
+	}
+
+	if (sax_data->unknown == 0) {
 		// We know where we are
-		for (index = 0; cria_0_0_1_tag_data[index].tag_name; index++)
-		{
-			if (strcmp (tagname, cria_0_0_1_tag_data[index].tag_name) == 0)
+		for (index = 0; cria_0_0_1_tag_data[index].tag_name; index++) {
+			if (strcmp (tagname, cria_0_0_1_tag_data[index].tag_name) == 0) {
 				break;
+			}
 		}
 	}
 
-	if (sax_data->unknown > 0 || cria_0_0_1_tag_data[index].tag_name == NULL)
-	{
+	if (sax_data->unknown > 0 || cria_0_0_1_tag_data[index].tag_name == NULL) {
 		g_debug ("cria_0_0_1_start_element(%i): unknown tag \"%s\"", __LINE__, tagname);
 		sax_data->unknown++;
-	}
-	else
-	{
-		if (cria_0_0_1_tag_data[index].tag_start)
-		{
+	} else {
+		if (cria_0_0_1_tag_data[index].tag_start) {
 			GHashTable	* attrs = NULL;
 
-			if (attributes != NULL)
+			if (attributes != NULL) {
 				attrs = hash_table_from_strarray (attributes);
+			}
 			
 			cria_0_0_1_tag_data[index].tag_start (attrs, sax_data);
-		}
-		else
-		{
+		} else {
 			g_debug ("cria_0_0_1_start_element(%i): skipping known tag \"%s\"", __LINE__, tagname);
 		}
 	}
@@ -931,6 +945,11 @@ cria_0_0_1_end_element (
 	
 	sax_data = (Sax001Data*) userdata;
 
+	if (sax_data->error != NULL) {
+		/* ignore this (see explanation in cria_0_0_1_start_element) */
+		return;
+	}
+
 	if (sax_data->unknown > 0)
 	{
 		g_debug ("cria_0_0_1_end_element(%i): unknown tag \"%s\"", __LINE__, tagname);
@@ -956,8 +975,7 @@ cria_0_0_1_end_element (
 }
 
 static void
-cria_0_0_1_start_document (gpointer userdata)
-{
+cria_0_0_1_start_document (gpointer userdata) {
 	Sax001Data	* sax_data;
 
 	/* ensure that context->userData is correctly filled */
@@ -966,8 +984,7 @@ cria_0_0_1_start_document (gpointer userdata)
 }
 
 static void
-cria_0_0_1_end_document (gpointer userdata)
-{
+cria_0_0_1_end_document (gpointer userdata) {
 	// TODO anything to do here?
 }
 
