@@ -40,22 +40,19 @@
 
 #define TITLE_STRING _("%s - criawips")
 
-struct _CriaSlideShowPrivate
-{
+struct _CriaSlideShowPrivate {
 	GtkWidget		* canvas;
 	GnomeCanvasGroup	* group;
 	GtkGestureHandler	* gesture_handler;
 };
 
-enum
-{
+enum {
 	PROP_0,
 	PROP_PRESENTATION,
 	PROP_SLIDE
 };
 
-enum
-{
+enum {
 	SIGNAL,
 	N_SIGNALS
 };
@@ -82,8 +79,7 @@ static	guint	cria_slide_show_signals[N_SIGNALS] = { 0 };
 static	void	cria_slide_show_signal	       (CriaSlideShow	* template,
 						const	gchar	* string);
 
-enum
-{
+enum {
 	KEYS_NONE,
 	KEYS_FORWARD,
 	KEYS_BACK,
@@ -106,17 +102,17 @@ cria_key_press_event_cb (
 
 	// TODO If we want to make it configurable we have to use a
 	// method instead of a switch statement
-	switch (event->keyval)
-	{
+	switch (event->keyval) {
 	case GDK_space:
 	case GDK_Right:
 	case GDK_KP_Enter:
 	case GDK_Return:
 	case GDK_Page_Down:
-		if (slide == cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget))))
+		if (slide == cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget)))) {
 			action = KEYS_CLOSE;
-		else
+		} else {
 			action = KEYS_FORWARD;
+		}
 		break;
 	case GDK_BackSpace:
 	case GDK_Left:
@@ -128,30 +124,24 @@ cria_key_press_event_cb (
 		break;
 	default:
 		/* after show ? */
-		if (slide == cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget))))
-		{
+		if (slide == cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget)))) {
 			action = KEYS_CLOSE;
-		}
-		else
-		{
+		} else {
 			g_debug ("cria_key_press_event(): this key is not handled");
 		}
 		break;
 	}
 
-	switch (action)
-	{
+	switch (action) {
 	case KEYS_FORWARD:
-		if (slide < cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget))))
-		{
+		if (slide < cria_presentation_n_slides (cria_slide_show_get_presentation (CRIA_SLIDE_SHOW (widget)))) {
 			cria_slide_show_set_slide (
 					CRIA_SLIDE_SHOW (widget),
 					slide + 1);
 		}
 		break;
 	case KEYS_BACK:
-		if (slide > 0)
-		{
+		if (slide > 0) {
 			cria_slide_show_set_slide (
 					CRIA_SLIDE_SHOW (widget),
 					slide - 1);
@@ -159,14 +149,14 @@ cria_key_press_event_cb (
 		break;
 	case KEYS_CLOSE:
 		gtk_object_destroy (GTK_OBJECT (widget));
+		break;
 	}
 
 	return retval;
 }
 
 static void
-cria_slide_show_class_init (CriaSlideShowClass	* cria_slide_show_class)
-{
+cria_slide_show_class_init (CriaSlideShowClass	* cria_slide_show_class) {
 	GObjectClass	* g_object_class;
 
 	g_debug ("cria_slide_show_class_init(%i): start", __LINE__);
@@ -232,8 +222,7 @@ cria_slide_show_clear (CriaSlideShow *self)
 
 	g_debug ("cria_slide_show_clear(%i): start", __LINE__);
 
-	if (self->priv->group)
-	{
+	if (self->priv->group) {
 		g_return_if_fail (GNOME_IS_CANVAS_ITEM (self->priv->group));
 		
 		gnome_canvas_item_hide (GNOME_CANVAS_ITEM (self->priv->group));
@@ -377,10 +366,8 @@ cria_slide_show_init (CriaSlideShow *self)
 	gtk_window_set_default_icon_from_file (
 			PACKAGE_DATA_DIR "/pixmaps/criawips.png",
 			&error);
-	if (error)
-	{
-		g_message (_("Couldn't set window icon, you have to live without; reason: %s"),
-				error->message);
+	if (error) {
+		g_message (_("Couldn't set window icon, you have to live without; reason: %s"), error->message);
 		g_error_free (error);
 	}
 
@@ -637,7 +624,7 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 						"justification", gtk_align,
 						"size-points", font_size,
 						"size-set", TRUE,
-						"text", (cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator))==_("block has no content"))?"":cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator)),
+						"text", (cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator))==_("the block has no content"))?"":cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator)),
 						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
 						"x", xpos,
 						"y", ypos,
