@@ -52,16 +52,14 @@ void		  cria_slide_show_set_slide	       (CriaSlideShow		* self,
 #define CRIA_IS_SLIDE_SHOW_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), CRIA_TYPE_SLIDE_SHOW))
 #define CRIA_SLIDE_SHOW_GET_CLASS(object)	(G_TYPE_INSTANCE_GET_CLASS((object), CRIA_TYPE_SLIDE_SHOW, CriaSlideShowClass))
 
-struct _CriaSlideShow
-{
+struct _CriaSlideShow {
 	GtkWindow		  base_instance;
 	CriaPresentation	* presentation;
 	guint			  slide;
 	CriaSlideShowPrivate	* priv;
 };
 
-struct _CriaSlideShowClass
-{
+struct _CriaSlideShowClass {
 	GtkWindowClass	  base_class;
 
 	guint		  screen_width;
@@ -75,3 +73,4 @@ struct _CriaSlideShowClass
 G_END_DECLS
 
 #endif /* SLIDE_SHOW_H */
+
